Changelog
---------
0.0.7 (2017-08-16)
~~~~~~~~~~~~~~~~~~~

- Adds an 'accepted' state.
  [msom]

0.0.6 (2017-08-15)
~~~~~~~~~~~~~~~~~~~

- Adds an issues column to the notices.
  [msom]

0.0.5 (2017-08-11)
~~~~~~~~~~~~~~~~~~~

- Fix default direction when ordering notices.
  [msom]

0.0.4 (2017-08-11)
~~~~~~~~~~~~~~~~~~~

- Allows to order notices.
  [msom]

- Adds an issue date column to the notices.
  [msom]

0.0.3 (2017-08-09)
~~~~~~~~~~~~~~~~~~~

- Adds an organization column to the notices.
  [msom]

0.0.2 (2017-08-09)
~~~~~~~~~~~~~~~~~~~

- Allows to filter notices by a search term.
  [msom]

- Allows to filter notices by user IDs.
  [msom]

0.0.1 (2017-07-14)
~~~~~~~~~~~~~~~~~~

- Initial Release
